#include <stdio.h>
#include <project.h>

#define MPU9250_DEFAULT_ADDRESS         0x68  //before 0xD1, alternative 0x68
#define MPU9250_ALT_DEFAULT_ADDRESS     0xD2   

#define MPU9250_SELF_TEST_X_GYRO        0x00
#define MPU9250_SELF_TEST_Y_GYRO        0x01
#define MPU9250_SELF_TEST_Z_GYRO        0x02

#define MPU9250_SELF_TEST_X_ACCEL       0x0D
#define MPU9250_SELF_TEST_Y_ACCEL       0x0E
#define MPU9250_SELF_TEST_Z_ACCEL       0x0F

#define MPU9250_XG_OFFSET_H             0x13
#define MPU9250_XG_OFFSET_L             0x14
#define MPU9250_YG_OFFSET_H             0x15
#define MPU9250_YG_OFFSET_L             0x16
#define MPU9250_ZG_OFFSET_H             0x17
#define MPU9250_ZG_OFFSET_L             0x18
#define MPU9250_SMPLRT_DIV              0x19
#define MPU9250_CONFIG                  0x1A
#define MPU9250_GYRO_CONFIG             0x1B
#define MPU9250_ACCEL_CONFIG            0x1C
#define MPU9250_ACCEL_CONFIG2           0x1D
#define MPU9250_LP_ACCEL_ODR            0x1E
#define MPU9250_WOM_THR                 0x1F

#define MPU9250_FIFO_EN                 0x23
#define MPU9250_I2C_MST_CTRL            0x24
#define MPU9250_I2C_SLV0_ADDR           0x25
#define MPU9250_I2C_SLV0_REG            0x26
#define MPU9250_I2C_SLV0_CTRL           0x27
#define MPU9250_I2C_SLV1_ADDR           0x28
#define MPU9250_I2C_SLV1_REG            0x29
#define MPU9250_I2C_SLV1_CTRL           0x2A
#define MPU9250_I2C_SLV2_ADDR           0x2B
#define MPU9250_I2C_SLV2_REG            0x2C
#define MPU9250_I2C_SLV2_CTRL           0x2D
#define MPU9250_I2C_SLV3_ADDR           0x2E
#define MPU9250_I2C_SLV3_REG            0x2F
#define MPU9250_I2C_SLV3_CTRL           0x30
#define MPU9250_I2C_SLV4_ADDR           0x31
#define MPU9250_I2C_SLV4_REG            0x32
#define MPU9250_I2C_SLV4_DO             0x33
#define MPU9250_I2C_SLV4_CTRL           0x34
#define MPU9250_I2C_SLV4_DI             0x35
#define MPU9250_I2C_MST_STATUS          0x36
#define MPU9250_INT_PIN_CFG             0x37
#define MPU9250_INT_ENABLE              0x38

#define MPU9250_INT_STATUS              0x3A
#define MPU9250_ACCEL_XOUT_H            0x3B
#define MPU9250_ACCEL_XOUT_L            0x3C
#define MPU9250_ACCEL_YOUT_H            0x3D
#define MPU9250_ACCEL_YOUT_L            0x3E
#define MPU9250_ACCEL_ZOUT_H            0x3F
#define MPU9250_ACCEL_ZOUT_L            0x40
#define MPU9250_TEMP_OUT_H              0x41
#define MPU9250_TEMP_OUT_L              0x42
#define MPU9250_GYRO_XOUT_H             0x43
#define MPU9250_GYRO_XOUT_L             0x44
#define MPU9250_GYRO_YOUT_H             0x45
#define MPU9250_GYRO_YOUT_L             0x46
#define MPU9250_GYRO_ZOUT_H             0x47
#define MPU9250_GYRO_ZOUT_L             0x48
#define MPU9250_EXT_SENS_DATA_00        0x49
#define MPU9250_EXT_SENS_DATA_01        0x4A
#define MPU9250_EXT_SENS_DATA_02        0x4B
#define MPU9250_EXT_SENS_DATA_03        0x4C
#define MPU9250_EXT_SENS_DATA_04        0x4D
#define MPU9250_EXT_SENS_DATA_05        0x4E
#define MPU9250_EXT_SENS_DATA_06        0x4F
#define MPU9250_EXT_SENS_DATA_07        0x50
#define MPU9250_EXT_SENS_DATA_08        0x51
#define MPU9250_EXT_SENS_DATA_09        0x52
#define MPU9250_EXT_SENS_DATA_10        0x53
#define MPU9250_EXT_SENS_DATA_11        0x54
#define MPU9250_EXT_SENS_DATA_12        0x55
#define MPU9250_EXT_SENS_DATA_13        0x56
#define MPU9250_EXT_SENS_DATA_14        0x57
#define MPU9250_EXT_SENS_DATA_15        0x58
#define MPU9250_EXT_SENS_DATA_16        0x59
#define MPU9250_EXT_SENS_DATA_17        0x5A
#define MPU9250_EXT_SENS_DATA_18        0x5B
#define MPU9250_EXT_SENS_DATA_19        0x5C
#define MPU9250_EXT_SENS_DATA_20        0x5D
#define MPU9250_EXT_SENS_DATA_21        0x5E
#define MPU9250_EXT_SENS_DATA_22        0x5F
#define MPU9250_EXT_SENS_DATA_23        0x60

#define MPU9250_I2C_SLV0_DO             0x63
#define MPU9250_I2C_SLV1_DO             0x64
#define MPU9250_I2C_SLV2_DO             0x65
#define MPU9250_I2C_SLV3_DO             0x66
#define MPU9250_I2C_MST_DELAY_CTRL      0x67
#define MPU9250_SIGNAL_PATH_RESET       0x68
#define MPU9250_MOT_DETECT_CTRL         0x69
#define MPU9250_USER_CTRL               0x6A
#define MPU9250_PWR_MGMT_1              0x6B
#define MPU9250_PWR_MGMT_2              0x6C

#define MPU9250_FIFO_COUNTH             0x72
#define MPU9250_FIFO_COUNTL             0x73
#define MPU9250_FIFO_R_W                0x74
#define MPU9250_WHO_AM_I                0x75
#define MPU9250_XA_OFFSET_H             0x77
#define MPU9250_XA_OFFSET_L             0x78

#define MPU9250_YA_OFFSET_H             0x7A
#define MPU9250_YA_OFFSET_L             0x7B

#define MPU9250_ZA_OFFSET_H             0x7D
#define MPU9250_ZA_OFFSET_L             0x7E

//reset values
#define WHOAMI_RESET_VAL                0x73
#define POWER_MANAGMENT_1_RESET_VAL     0x01
#define DEFAULT_RESET_VALUE             0x00

#define WHOAMI_DEFAULT_VAL              0x73

//CONFIG register masks
#define MPU9250_FIFO_MODE_MASK          0x40
#define MPU9250_EXT_SYNC_SET_MASK       0x38
#define MPU9250_DLPF_CFG_MASK           0x07

//GYRO_CONFIG register masks
#define MPU9250_XGYRO_CTEN_MASK         0x80
#define MPU9250_YGYRO_CTEN_MASK         0x40
#define MPU9250_ZGYRO_CTEN_MASK         0x20
#define MPU9250_GYRO_FS_SEL_MASK        0x18
#define MPU9250_FCHOICE_B_MASK          0x03

#define MPU9250_GYRO_FULL_SCALE_250DPS  0
#define MPU9250_GYRO_FULL_SCALE_500DPS  1
#define MPU9250_GYRO_FULL_SCALE_1000DPS 2
#define MPU9250_GYRO_FULL_SCALE_2000DPS 3

//ACCEL_CONFIG register masks
#define MPU9250_AX_ST_EN_MASK           0x80
#define MPU9250_AY_ST_EN_MASK           0x40
#define MPU9250_AZ_ST_EN_MASK           0x20
#define MPU9250_ACCEL_FS_SEL_MASK       0x18

#define MPU9250_FULL_SCALE_2G           0
#define MPU9250_FULL_SCALE_4G           1
#define MPU9250_FULL_SCALE_8G           2
#define MPU9250_FULL_SCALE_16G          3

//ACCEL_CONFIG_2 register masks
#define MPU9250_ACCEL_FCHOICE_B_MASK    0xC0
#define MPU9250_A_DLPF_CFG_MASK         0x03

//LP_ACCEL_ODR register masks
#define MPU9250_LPOSC_CLKSEL_MASK       0x0F

//FIFO_EN register masks
#define MPU9250_TEMP_FIFO_EN_MASK       0x80
#define MPU9250_GYRO_XOUT_MASK          0x40
#define MPU9250_GYRO_YOUT_MASK          0x20
#define MPU9250_GYRO_ZOUT_MASK          0x10
#define MPU9250_ACCEL_MASK              0x08
#define MPU9250_SLV2_MASK               0x04
#define MPU9250_SLV1_MASK               0x02
#define MPU9250_SLV0_MASK               0x01

//I2C_MST_CTRL register masks
#define MPU9250_MULT_MST_EN_MASK        0x80
#define MPU9250_WAIT_FOR_ES_MASK        0x40
#define MPU9250_SLV_3_FIFO_EN_MASK      0x20
#define MPU9250_I2C_MST_P_NSR_MASK      0x10
#define MPU9250_I2C_MST_CLK_MASK        0x0F

//I2C_SLV0_ADDR register masks
#define MPU9250_I2C_SLV0_RNW_MASK       0x80
#define MPU9250_I2C_ID_0_MASK           0x7F

//I2C_SLV0_CTRL register masks
#define MPU9250_I2C_SLV0_EN_MASK        0x80
#define MPU9250_I2C_SLV0_BYTE_SW_MASK   0x40
#define MPU9250_I2C_SLV0_REG_DIS_MASK   0x20
#define MPU9250_I2C_SLV0_GRP_MASK       0x10
#define MPU9250_I2C_SLV0_LENG_MASK      0x0F

//I2C_SLV1_ADDR register masks
#define MPU9250_I2C_SLV1_RNW_MASK       0x80
#define MPU9250_I2C_ID_1_MASK           0x7F

//I2C_SLV1_CTRL register masks
#define MPU9250_I2C_SLV1_EN_MASK        0x80
#define MPU9250_I2C_SLV1_BYTE_SW_MASK   0x40
#define MPU9250_I2C_SLV1_REG_DIS_MASK   0x20
#define MPU9250_I2C_SLV1_GRP_MASK       0x10
#define MPU9250_I2C_SLV1_LENG_MASK      0x0F

//I2C_SLV2_ADDR register masks
#define MPU9250_I2C_SLV2_RNW_MASK       0x80
#define MPU9250_I2C_ID_2_MASK           0x7F

//I2C_SLV2_CTRL register masks
#define MPU9250_I2C_SLV2_EN_MASK        0x80
#define MPU9250_I2C_SLV2_BYTE_SW_MASK   0x40
#define MPU9250_I2C_SLV2_REG_DIS_MASK   0x20
#define MPU9250_I2C_SLV2_GRP_MASK       0x10
#define MPU9250_I2C_SLV2_LENG_MASK      0x0F

//I2C_SLV3_ADDR register masks
#define MPU9250_I2C_SLV3_RNW_MASK       0x80
#define MPU9250_I2C_ID_3_MASK           0x7F

//I2C_SLV3_CTRL register masks
#define MPU9250_I2C_SLV3_EN_MASK        0x80
#define MPU9250_I2C_SLV3_BYTE_SW_MASK   0x40
#define MPU9250_I2C_SLV3_REG_DIS_MASK   0x20
#define MPU9250_I2C_SLV3_GRP_MASK       0x10
#define MPU9250_I2C_SLV3_LENG_MASK      0x0F

//I2C_SLV4_ADDR register masks
#define MPU9250_I2C_SLV4_RNW_MASK       0x80
#define MPU9250_I2C_ID_4_MASK           0x7F

//I2C_SLV4_CTRL register masks
#define MPU9250_I2C_SLV4_EN_MASK        0x80
#define MPU9250_SLV4_DONE_INT_EN_MASK   0x40
#define MPU9250_I2C_SLV4_REG_DIS_MASK   0x20
#define MPU9250_I2C_MST_DLY_MASK        0x1F

//I2C_MST_STATUS register masks
#define MPU9250_PASS_THROUGH_MASK       0x80
#define MPU9250_I2C_SLV4_DONE_MASK      0x40
#define MPU9250_I2C_LOST_ARB_MASK       0x20
#define MPU9250_I2C_SLV4_NACK_MASK      0x10
#define MPU9250_I2C_SLV3_NACK_MASK      0x08
#define MPU9250_I2C_SLV2_NACK_MASK      0x04
#define MPU9250_I2C_SLV1_NACK_MASK      0x02
#define MPU9250_I2C_SLV0_NACK_MASK      0x01

//INT_PIN_CFG register masks
#define MPU9250_ACTL_MASK               0x80
#define MPU9250_OPEN_MASK               0x40
#define MPU9250_LATCH_INT_EN_MASK       0x20
#define MPU9250_INT_ANYRD_2CLEAR_MASK   0x10
#define MPU9250_ACTL_FSYNC_MASK         0x08
#define MPU9250_FSYNC_INT_MODE_EN_MASK  0x04
#define MPU9250_BYPASS_EN_MASK          0x02

//INT_ENABLE register masks
#define MPU9250_WOM_EN_MASK             0x40
#define MPU9250_FIFO_OFLOW_EN_MASK      0x10
#define MPU9250_FSYNC_INT_EN_MASK       0x08
#define MPU9250_RAW_RDY_EN_MASK         0x01

//INT_STATUS register masks
#define MPU9250_WOM_INT_MASK            0x40
#define MPU9250_FIFO_OFLOW_INT_MASK     0x10
#define MPU9250_FSYNC_INT_MASK          0x08
#define MPU9250_RAW_DATA_RDY_INT_MASK   0x01

//I2C_MST_DELAY_CTRL register masks
#define MPU9250_DELAY_ES_SHADOW_MASK    0x80
#define MPU9250_I2C_SLV4_DLY_EN_MASK    0x10
#define MPU9250_I2C_SLV3_DLY_EN_MASK    0x08
#define MPU9250_I2C_SLV2_DLY_EN_MASK    0x04
#define MPU9250_I2C_SLV1_DLY_EN_MASK    0x02
#define MPU9250_I2C_SLV0_DLY_EN_MASK    0x01

//SIGNAL_PATH_RESET register masks
#define MPU9250_GYRO_RST_MASK           0x04
#define MPU9250_ACCEL_RST_MASK          0x02
#define MPU9250_TEMP_RST_MASK           0x01

//MOT_DETECT_CTRL register masks
#define MPU9250_ACCEL_INTEL_EN_MASK     0x80
#define MPU9250_ACCEL_INTEL_MODE_MASK   0x40

//USER_CTRL register masks
#define MPU9250_FIFO_EN_MASK            0x40
#define MPU9250_I2C_MST_EN_MASK         0x20
#define MPU9250_I2C_IF_DIS_MASK         0x10
#define MPU9250_FIFO_RST_MASK           0x04
#define MPU9250_I2C_MST_RST_MASK        0x02
#define MPU9250_SIG_COND_RST_MASK       0x01

//PWR_MGMT_1 register masks
#define MPU9250_H_RESET_MASK            0x80
#define MPU9250_SLEEP_MASK              0x40
#define MPU9250_CYCLE_MASK              0x20
#define MPU9250_GYRO_STANDBY_CYCLE_MASK 0x10
#define MPU9250_PD_PTAT_MASK            0x08
#define MPU9250_CLKSEL_MASK             0x07

//PWR_MGMT_2 register masks
#define MPU9250_DISABLE_XA_MASK         0x20
#define MPU9250_DISABLE_YA_MASK         0x10
#define MPU9250_DISABLE_ZA_MASK         0x08
#define MPU9250_DISABLE_XG_MASK         0x04
#define MPU9250_DISABLE_YG_MASK         0x02
#define MPU9250_DISABLE_ZG_MASK         0x01

#define MPU9250_DISABLE_XYZA_MASK       0x38
#define MPU9250_DISABLE_XYZG_MASK       0x07

//Magnetometer register maps
#define MPU9250_MAG_ADDRESS             0x0C

#define MPU9250_MAG_WIA                 0x00
#define MPU9250_MAG_INFO                0x01
#define MPU9250_MAG_ST1                 0x02
#define MPU9250_MAG_XOUT_L              0x03
#define MPU9250_MAG_XOUT_H              0x04
#define MPU9250_MAG_YOUT_L              0x05
#define MPU9250_MAG_YOUT_H              0x06
#define MPU9250_MAG_ZOUT_L              0x07
#define MPU9250_MAG_ZOUT_H              0x08
#define MPU9250_MAG_ST2                 0x09
#define MPU9250_MAG_CNTL                0x0A
#define MPU9250_MAG_RSV                 0x0B //reserved mystery meat
#define MPU9250_MAG_ASTC                0x0C
#define MPU9250_MAG_TS1                 0x0D
#define MPU9250_MAG_TS2                 0x0E
#define MPU9250_MAG_I2CDIS              0x0F
#define MPU9250_MAG_ASAX                0x10
#define MPU9250_MAG_ASAY                0x11
#define MPU9250_MAG_ASAZ                0x12

//Magnetometer register masks
#define MPU9250_MAG_WIA_MASK 0x48
#define MPU9250_MAG_HOFL_MASK 0x08
 


void printconsole(int16_t value){
    char writtenString[15];
    sprintf(writtenString,"%d", value);
    UART_PutString(writtenString);
	
   // UART_UartPutString(" "); //print backspace character
    }

void printfloatconsole(float value){
    char writtenString[31];
    int32_t value2 = (int32_t)value;
    sprintf(writtenString,"%d", value2);
    UART_PutString(writtenString);
    }




uint8_t deviceSelect(const uint8_t choise) {
	if(choise!=1)
		return MPU9250_DEFAULT_ADDRESS;
	else
		return MPU9250_MAG_ADDRESS;
}

//For all read and write functions, first argument (device_selection) determine
//device to be connected. 0 is for mpu9250 chip, 1 is for the magnetometer 
//chip inside the main chip

int8_t readRegister(const uint8_t device_selection, const uint8_t register_addr) {
    uint8 reg_addr[1]={register_addr};
    uint8 buffer[1];
	uint8_t selected_address = deviceSelect(device_selection);
       
    I2C_MasterWriteBuf(selected_address, reg_addr, 1, I2C_MODE_NO_STOP); 
        //write reg addr to bus
            
    while (0u == (I2C_MasterStatus() & I2C_MSTAT_WR_CMPLT))
       {}; //wait until transfer completed 
    
        
    I2C_MasterReadBuf(selected_address, buffer, 1, I2C_MODE_REPEAT_START); 
        //read data from bus
        
    while (0u == (I2C_MasterStatus() & I2C_MSTAT_RD_CMPLT))
       {}; // wait until transfer completed
    
    
    
    return buffer[0]; //return the data returned from the register
}




void writeRegister(const uint8_t device_selection, const uint8_t register_addr, 
const int8_t regvalue) {

    uint8 buffer[2]={register_addr,regvalue};
	uint8_t selected_address = deviceSelect(device_selection);
       
    I2C_MasterWriteBuf(selected_address, buffer, 2, I2C_MODE_COMPLETE_XFER); 
        //write reg addr to bus
    while (0u == (I2C_MasterStatus() & I2C_MSTAT_WR_CMPLT))
       {} // wait until transfer completed
}



int16_t readRegisters(const uint8_t device_selection, const uint8_t msb_register, 
const uint8_t lsb_register) {
	uint8_t msb = readRegister(device_selection, msb_register);
    uint8_t lsb = readRegister(device_selection, lsb_register);
    return (((int16_t)msb) << 8) | lsb;
}


void writeRegisters(const uint8_t device_selection, const uint8_t msb_register_addr, 
const uint8_t lsb_register_addr, const int16_t regvalue) {      
    writeRegister(device_selection, msb_register_addr, (uint8_t)((regvalue&0xFF00)>>8));
    writeRegister(device_selection, lsb_register_addr, (uint8_t)(regvalue&0x00FF));
}


void writeMaskedRegister(const uint8_t device_selection, const uint8_t register_addr,
const uint8_t mask, const uint8_t value) {
	uint8_t masked_value = (mask & value);
    uint8_t regvalue = readRegister(device_selection, register_addr);
    regvalue = regvalue & ~mask; // Zero Mask bits
    regvalue = regvalue | masked_value; //Set Mask value
    writeRegister(device_selection, register_addr, regvalue);  //change certain bits of register
}
    


int8_t readMaskedRegister(const uint8_t device_selection, const uint8_t register_addr, 
const uint8_t mask) {
    uint8_t data = readRegister(device_selection, register_addr);
    return (data & mask);
}



uint8_t testConnection(void) {
      return (readRegister(0, MPU9250_WHO_AM_I)== WHOAMI_DEFAULT_VAL);
}


void reset9250(void) {
    writeMaskedRegister(0, MPU9250_PWR_MGMT_1, MPU9250_H_RESET_MASK, 0xFF);
    //reset full device
    CyDelay(100);
    //time delay after reset
}



void setFullScaleRanges (uint8_t gyroscale, uint8_t accelscale){
    writeMaskedRegister(0, MPU9250_GYRO_CONFIG, MPU9250_GYRO_FS_SEL_MASK, gyroscale<<3);
    writeMaskedRegister(0, MPU9250_ACCEL_CONFIG, MPU9250_ACCEL_FS_SEL_MASK, accelscale<<3);
}



void init9250(void) {
    
   if(testConnection())         // check if device responds or not
        UART_PutString(" Connected to Sensor");
    	
    else
        {
        UART_PutString(" Connection Failed");
    //    while(1){}
        }  
    
    
  writeMaskedRegister(0, MPU9250_PWR_MGMT_1, MPU9250_SLEEP_MASK, 0x00);
    //deactivate sleep mode
   
// get stable time source
  writeMaskedRegister(0, MPU9250_PWR_MGMT_1, MPU9250_CLKSEL_MASK, 1); 
    //Set clock source to be PLL with x-axis gyroscope reference, bits 2:0=001

// Configure Interrupts and Bypass Enable
   writeMaskedRegister(0, MPU9250_INT_PIN_CFG, MPU9250_LATCH_INT_EN_MASK, 0x00);
        // Set interrupt pin active high, push-pull, if last argument is 0xFF
        // clear interrupt on read of INT_STATUS , if 0x00 clear after 50us 
        // INT_STATUS is read inside newDataAvailable() function.
   writeMaskedRegister(0, MPU9250_INT_ENABLE, MPU9250_RAW_RDY_EN_MASK, 0xFF); 
        // Enable data ready (bit 0) interrupt

// Configure Gyro and Accelerometer
// Disable FSYNC and set gyro and temp
// sensors bandwidths to 20 and 20 Hz, respectively; 
// DLPF_CFG = bits 2:0 = 0b100; this sets the sample rate at 1 kHz for both
// Maximum delay is 9.9 ms which is below than 100 Hz maximum rate
  writeMaskedRegister(0, MPU9250_CONFIG, MPU9250_DLPF_CFG_MASK, 4);
    //Write DLPF_CFG_MASK, bits 7:0=002

// Set sample rate = gyroscope output rate/(1 + SMPLRT_DIV)
  writeRegister(0, MPU9250_SMPLRT_DIV, 9);  
// Use a 100 Hz rate; the same rate set in CONFIG above

// Set accelerometer sample rate configuration
// Set accelerometer rate to 1 kHz and bandwidth to 41 Hz, delay=11.8ms
writeMaskedRegister(0, MPU9250_ACCEL_CONFIG2, MPU9250_ACCEL_FCHOICE_B_MASK, 0x00);  
//writeMaskedRegister(0, MPU9250_ACCEL_CONFIG2, MPU9250_A_DLPF_CFG_MASK, 3); 
    // Write new ACCEL_CONFIG2 register value

writeMaskedRegister(0, MPU9250_ACCEL_CONFIG2, MPU9250_A_DLPF_CFG_MASK, 6); 

 // The accelerometer, gyro, and thermometer are set to 1 kHz sample rates, 
 // but all these rates are further reduced by a factor of 10 to 100 Hz
//because of the SMPLRT_DIV setting


//writeRegisters(0, MPU9250_XA_OFFSET_H, MPU9250_XA_OFFSET_L, 0);
}

float mag_adjustment_factor[3];   //factor that must be multiplied with measured data
void initMagnetometer (){
    uint8_t adjusment_value[3];     //store data read from adjusment registers
    writeMaskedRegister(0, MPU9250_USER_CTRL, MPU9250_I2C_MST_EN_MASK, 0x00);
        //Disable I2C master mode
    writeMaskedRegister(0, MPU9250_INT_PIN_CFG, MPU9250_BYPASS_EN_MASK, 0xFF);
        //Enable ByPass mode to control magnetometer through PSOC master device
   
    
    if(readRegister(1, MPU9250_MAG_WIA)==0x48)
    UART_PutString(" Connected to Magnetometer");
    else
    UART_PutString(" Failed to connect magnetometer");
   
   
    //  ***Magnetometer adjustment starts***    
    writeRegister(1, MPU9250_MAG_CNTL, 0x00); // Power down magnetometer  
    CyDelay(10);
    writeRegister(1, MPU9250_MAG_CNTL, 0x0F);// Enter Fuse ROM access mode
    CyDelay(10);
    adjusment_value[0] = readRegister(0, MPU9250_MAG_ASAX);
    adjusment_value[1] = readRegister(0, MPU9250_MAG_ASAY);
    adjusment_value[2] = readRegister(0, MPU9250_MAG_ASAZ);
    //Read x-axis, y-axis, z-axis sensitivity adjustment values
    uint8_t i;
    for(i=0;i<3;i++) {
    mag_adjustment_factor[i] =  (float)(adjusment_value[i] - 128)/256.0f + 1.0f;  
    // adjusment factor calculated according to datasheet
    }
    //  ***Magnetometer adjustment ends***  
    
    
    
    writeRegister(1, MPU9250_MAG_CNTL, 0x00); // Power down magnetometer  
    CyDelay(100);
    
    
    writeRegister(1, MPU9250_MAG_CNTL, 0b00010110); //enable the magnetometer
    // in continuous measurement mode 2 (100HZ rate) and 16 bit data output enabled
    CyDelay(100);
 
}


uint8_t newDataAvailable(void) {
    if(readRegister(0, MPU9250_INT_ENABLE) & MPU9250_RAW_RDY_EN_MASK)
        return (readRegister(0, MPU9250_INT_STATUS) & MPU9250_RAW_DATA_RDY_INT_MASK);
    else
    {   CyDelay(10);
    readRegister(0, MPU9250_INT_STATUS); //this register is needed to read
    //to end interupt pulse
        return (1);
    }
}


//int8_t gyroBias[3], accelBias[3]; 
void calibrateDevices (void){
    
    /*
Note about offset registers of mpu9255. Bias registers transforms themselves 
automatically to the chosen fullscale settings. 
It is needed to apply bias in 
+1000 dps fullscale setting for gyro, and  +-16g fullscale setting for accel.
Gyro bias registers are empty initially. But accelerometer bias registers are not empty 
initially. It is needed to preserve these values and add new bias values to them. 
Note that addresses of accellerometer bias registers  are not sequential.
    */
   
    
    uint8_t i, j;
    int16_t gyro_bias[3] = {0, 0, 0}, accel_bias[3] = {0, 0, 0};
    int32_t temp; //take 10 sample of any axis data


    for(i=0;i<3;i++){
        accel_bias[i]=readRegisters(0, MPU9250_XA_OFFSET_H+3*i, 
            MPU9250_XA_OFFSET_L+3*i);
    }
    

    if(accel_bias[2]>0)     //hold gravity data
    accel_bias[2]+=2046;
    else
    accel_bias[2]-=2046;
    
    
   setFullScaleRanges(0,0);  //maximum sensitivity     
   CyDelay(10); 
    
    for(j=0;j<3;j++){
        temp=0;
        for(i=0;i<100;i++){
         temp=temp+readRegisters(0, MPU9250_GYRO_XOUT_H+2*j, MPU9250_GYRO_XOUT_L+2*j);
         CyDelay(5);
        }
        temp=temp/100;  // get average
        temp=temp/4;   // since bias register require 1000 dps Full Scale settings,
        //we measured in 250 dps settings. That's why we divide by 4 again.
        
         writeRegisters(0, MPU9250_XG_OFFSET_H+2*j, MPU9250_XG_OFFSET_L+2*j,
         -(int16_t)temp);
        
        
        for(i=0;i<100;i++){
         temp=temp+readRegisters(0, MPU9250_ACCEL_XOUT_H+2*j, MPU9250_ACCEL_XOUT_L+2*j);
         CyDelay(5);
        }
        temp=temp/100;  // get average
        temp=temp/8;   // since bias register require 16g Full Scale settings,
        //we measured in 2g settings. That's why we divide by 8 again.
        
               
         writeRegisters(0, MPU9250_XA_OFFSET_H+3*j, MPU9250_XA_OFFSET_L+3*j,
         accel_bias[j]-(((int16_t)temp)&0xFFFE));    //Add offset to existing one.
        //preserve last bit
     
    }     
   
}


void calibrateMagnetometer()
{
    //Magnetometer Calibration Functions
}

int16_t getAccelerationX(void) {
    
        return (int16_t) readRegisters(0, MPU9250_ACCEL_XOUT_H, MPU9250_ACCEL_XOUT_L);
}




int16_t getAccelerationY(void) {
   
        return (int16_t) readRegisters(0, MPU9250_ACCEL_YOUT_H, MPU9250_ACCEL_YOUT_L);
}




int16_t getAccelerationZ(void) {
    
        return (int16_t) readRegisters(0, MPU9250_ACCEL_ZOUT_H, MPU9250_ACCEL_ZOUT_L);
}



int16_t getRotationX(void) {
    
        return (int16_t) readRegisters(0, MPU9250_GYRO_XOUT_H, MPU9250_GYRO_XOUT_L); 
   
}



int16_t getRotationY(void) {
    
        return (int16_t) readRegisters(0, MPU9250_GYRO_YOUT_H, MPU9250_GYRO_YOUT_L); 
   
}


int16_t getRotationZ(void) {
    
        return (int16_t) readRegisters(0, MPU9250_GYRO_ZOUT_H, MPU9250_GYRO_ZOUT_L); 
   
}


int16_t getDirectionX(void) {
         return (int16_t)
       mag_adjustment_factor[0]*readRegisters(1, MPU9250_MAG_XOUT_H, MPU9250_MAG_XOUT_L); 
   }

int16_t getDirectionY(void) {
    
        return (int16_t) 
       mag_adjustment_factor[1]*readRegisters(1, MPU9250_MAG_YOUT_H, MPU9250_MAG_YOUT_L); 
   }

int16_t getDirectionZ(void) {
    
        return (int16_t) 
        mag_adjustment_factor[2]*readRegisters(1, MPU9250_MAG_ZOUT_H, MPU9250_MAG_ZOUT_L); 
  }



void getAcceleration(int16_t* ax, int16_t* ay, int16_t* az) {
    *ax = getAccelerationX();
    *ay = getAccelerationY();
    *az = getAccelerationZ();
}

void getRotation(int16_t* gx, int16_t* gy, int16_t* gz) {
    *gx = getRotationX();      //sensors must be appropriated 
   // to filters input
    *gy = getRotationY();
    *gz = getRotationZ();
}


void getDirection(int16_t* mx, int16_t* my, int16_t* mz) {
    *mx = getDirectionX();
    *my = getDirectionY();
    *mz = getDirectionZ();
  
    if(readMaskedRegister(1, MPU9250_MAG_ST2, MPU9250_MAG_HOFL_MASK)){
    UART_PutString("Magnetic sensor overflow, data is not correct");
    }
    //ST2 register must be read after the measurement operation to 
    //prepare sensor new measurement
       
}

// ***Power Save Mode functions***
/*
void Sleep (void){
    CySysPmSleep(); 
}
*/
//interrupt handler for sleep mode activation/deactivation
//used with init9250 function
/*
CY_ISR(timerInterruptHandler)  { //if there is no input in 3 seconds
    // and program freeze in main loop 
    Timer_ClearInterrupt(Timer_INTR_MASK_TC);
    Sleep();
    //    CySoftwareReset();  //restart PSOC
    }
*/
/*
CY_ISR(pinInterruptHandler) { //if sensor interrupt pin triggers psoc interrupt
    
    Timer_Start();
    Timer_WriteCounter(0);   //restart timer to count another 3 seconds
    Pin_ClearInterrupt();
    //CySysPmSleep();
    }

*/
/*
void initPowerSaveMode (void) {
   Timer_Start();
   timerInterrupt_StartEx(timerInterruptHandler);  //initialize timer interrupt
   pinInterrupt_StartEx(pinInterruptHandler);   //initialize pin interrupt
  
    
   
    writeMaskedRegister(0, MPU9250_PWR_MGMT_2, MPU9250_DISABLE_XYZG_MASK, 0xFF); 
        //disable gyro
    writeMaskedRegister(0, MPU9250_ACCEL_CONFIG2, MPU9250_FCHOICE_B_MASK, 0xFF);
    writeMaskedRegister(0, MPU9250_ACCEL_CONFIG2, MPU9250_DLPF_CFG_MASK, 0x01);
        //set digital low pass filter for accel to 184HZ
    writeRegister(0, MPU9250_INT_ENABLE, 0x40); //enable only wake on motion interrupt
    writeMaskedRegister(0, MPU9250_MOT_DETECT_CTRL, MPU9250_ACCEL_INTEL_EN_MASK, 0xFF);
    writeMaskedRegister(0, MPU9250_MOT_DETECT_CTRL, MPU9250_ACCEL_INTEL_MODE_MASK, 0xFF);
        //enable accel hardware intelligence
    writeRegister(0, MPU9250_WOM_THR, 10);
        //set motion threshold. 1~255 LSBs (0~1020mg)
    writeMaskedRegister(0, MPU9250_LP_ACCEL_ODR, MPU9250_LPOSC_CLKSEL_MASK, 3);
        //set frequency of wake up. Lposc_clksel [3:0] = 0.24Hz ~ 500Hz
 // writeMaskedRegister(0, MPU9250_PWR_MGMT_1, MPU9250_CYCLE_MASK, 0xFF);
        //Enable Cycle Mode (Accel Low Power Mode):
  
}
*/
// ***End of Power Save Mode functions***


float convertRawGyro(int gRaw) {
  // since we are using 250 degrees/seconds range
  // -250 maps to a raw value of -32768
  // +250 maps to a raw value of 32767
     
   float g = (gRaw * 250) / 32768.0;
   return g;


}

float convertRawAcceleration(int aRaw) {
  // since we are using 2G range
  // -2g maps to a raw value of -32768
  // +2g maps to a raw value of 32767
  
   float a = (aRaw * 2.0) / 32768.0;
   return a;
}

float convertRawDirection(int aRaw) {
  
  // for 16 bit mode LSB is equal to 0.15mT
  
  float a = aRaw * 0.15;
  return a;
}




/* [] END OF FILE */
