/*******************************************************************************
* File Name: main.c
*
* Version: 1.10
*
* Description:
*  This is source code for example project of the SPI Master component.
*  Parameters used:
*   Mode                CPHA == 0, CPOL == 0                
*   Data lines          MOSI+MISO
*   Shift direction     MSB First
*   DataBits:           8 
*   Bit Rate            1 Mbps
*   Clock source        External 
*
*  SPI communication test using DMA. 8 bytes are transmitted
*  between SPI Master and SPI Slave.
*  Received data are displayed on LCD. 
*
********************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#include <project.h>
#include <mpu92xx.h>
void DmaTxConfiguration(void);
void DmaRxConfiguration(void);

/* DMA Configuration for DMA_TX */
#define DMA_TX_BYTES_PER_BURST      (1u)
#define DMA_TX_REQUEST_PER_BURST    (1u)
#define DMA_TX_SRC_BASE             (CYDEV_SRAM_BASE)
#define DMA_TX_DST_BASE             (CYDEV_PERIPH_BASE)

/* DMA Configuration for DMA_RX */
#define DMA_RX_BYTES_PER_BURST      (1u)
#define DMA_RX_REQUEST_PER_BURST    (1u)
#define DMA_RX_SRC_BASE             (CYDEV_PERIPH_BASE)
#define DMA_RX_DST_BASE             (CYDEV_SRAM_BASE)

#define BUFFER_SIZE                 (8u)
#define STORE_TD_CFG_ONCMPLT        (1u)

/* Variable declarations for DMA_TX*/
uint8 txChannel;
uint8 txTD;

/* Variable declarations for DMA_RX */
uint8 rxChannel;
uint8 rxTD;

uint8 clearTxTD;
uint8 clearRxTD;
uint8 TD_InterruptControl;

uint8 accSaveActive=0;
uint8 a=0, stateForAcc=0;
/* Data buffers */
uint8 txBuffer [BUFFER_SIZE] = {MPUREG_ACCEL_XOUT_H|0x80, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u};
uint8 rxBuffer[BUFFER_SIZE];

/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
*  Main function performs following functions:
*   1. Starts Character LCD and print project info
*   2. Starts SPI Master component
*   3. Configures the DMA transfer for RX and TX directions
*   4. Displays the results on Character LCD
*   
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/

CY_ISR(isrDmaDone){
	accSaveActive=1;
}

volatile uint8_t rx_Status;
volatile uint8_t tx_Status;
volatile uint8_t InterruptControl;

int main()
{
	SPIM_Start();
    SPIM_TX_STATUS_MASK_REG&=(~SPIM_INT_ON_TX_EMPTY);
	SPIM_TX_STATUS_MASK_REG|=(SPIM_INT_ON_TX_EMPTY);

    InterruptControl=SPIM_TX_STATUS_MASK_REG;
	uint8 i;
    init(1,500);
	CyDelay(1);
	i = whoami();

    CyDelay(2000u);
    isr_1_StartEx(isrDmaDone);
    DmaTxConfiguration();
    DmaRxConfiguration();
    
    
    CyDmaChEnable(rxChannel, 1);
    CyDmaChEnable(txChannel, 1);

    for(;;)
    {	
		//SPIM_ClearRxBuffer();
		//SPIM_ClearTxBuffer();
		//SPIM_TX_STATUS_REG;
		//CyDmaChEnable(rxChannel, STORE_TD_CFG_ONCMPLT);
		//CyDmaChEnable(txChannel, STORE_TD_CFG_ONCMPLT);
		SPIM_TX_STATUS_MASK_REG|=(SPIM_INT_ON_TX_EMPTY);
		i= SPIM_ReadTxStatus();
		while (0u == (SPIM_ReadTxStatus() & SPIM_STS_SPI_DONE)) {}
		if(accSaveActive==1){
            accSaveActive=0;
            CyDmaChStatus(txChannel,&a,0); 
            
				if (stateForAcc){
	                //FS_Write(pFile, (uint8*)rxGyroBuffer, (BUFFER_SIZE*2));
	                //stateForAcc= 0; 
	                a=0;
	            }
	            else{
	                //FS_Write(p2File, (uint8*)rxBuffer, (BUFFER_SIZE*2)); 
	                //stateForAcc= 1;
	                //a=2;
					
				}
			}
    }
}

    
/*******************************************************************************
* Function Name: DmaTxConfiguration
********************************************************************************
* Summary:
*  Configures the DMA transfer for TX direction
*   
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void DmaTxConfiguration()
{
    /* Init DMA, 1 byte bursts, each burst requires a request */ 
    txChannel = DMA_TX_DmaInitialize(DMA_TX_BYTES_PER_BURST, DMA_TX_REQUEST_PER_BURST, 
                                        HI16(txBuffer), HI16(SPIM_TXDATA_PTR));

    txTD = CyDmaTdAllocate();
	TD_InterruptControl = CyDmaTdAllocate();

    CyDmaTdSetConfiguration(txTD, BUFFER_SIZE, TD_InterruptControl,TD_INC_SRC_ADR);
	CyDmaTdSetConfiguration(TD_InterruptControl, 1, txTD, 	0);


    CyDmaTdSetAddress(txTD, LO16((uint32)txBuffer), LO16((uint32) SPIM_TXDATA_PTR));
	CyDmaTdSetAddress(TD_InterruptControl, LO16((uint32)&InterruptControl), LO16((uint32)&SPIM_TX_STATUS_MASK_REG));
	//CyDmaTdSetAddress(clearRxTD, LO16((uint32)&SPIM_TX_STATUS_REG), LO16((uint32)rxBuffer));
	//CyDmaTdSetAddress(clearTxTD, LO16((uint32)&SPIM_RX_STATUS_REG), LO16((uint32)tx_Status));
    CyDmaChSetRequest(txChannel, CPU_TERM_CHAIN);
	CyDmaChEnable(txChannel, 1);
    /* Associate the TD with the channel */
    CyDmaChSetInitialTd(txChannel, txTD); 
	CyDmaChEnable(txChannel, 1);
}    


/*******************************************************************************
* Function Name: DmaRxConfiguration
********************************************************************************
* Summary:
*  Configures the DMA transfer for RX direction
*   
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void DmaRxConfiguration()
{ 
    /* Init DMA, 1 byte bursts, each burst requires a request */ 
    rxChannel = DMA_RX_DmaInitialize(DMA_RX_BYTES_PER_BURST, DMA_RX_REQUEST_PER_BURST,
                                     HI16(DMA_RX_SRC_BASE), HI16(DMA_RX_DST_BASE));

    rxTD = CyDmaTdAllocate();
    
    /* Configure this Td as follows:
    *  - Increment the destination address, but not the source address
    */
    CyDmaTdSetConfiguration(rxTD, BUFFER_SIZE, rxTD, TD_INC_DST_ADR| DMA_RX__TD_TERMOUT_EN);

    /* From the SPIM to the memory */
    CyDmaTdSetAddress(rxTD, LO16((uint32)SPIM_RXDATA_PTR), LO16((uint32)rxBuffer));

    /* Associate the TD with the channel */
    CyDmaChSetInitialTd(rxChannel, rxTD);
}
   
	
/* [] END OF FILE */
